@@ -1,8 +1,7 @@
 package org.sqlite;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assumptions.*;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assumptions.assumeThat;
 
 import java.sql.Connection;
 import java.sql.DriverManager;
@@ -43,8 +42,8 @@ public class ExtensionTest {
         ResultSet rs =
                 stat.executeQuery(
                         "select rowid, name, ingredients from recipe where ingredients match 'onions'");
-        assertTrue(rs.next());
-        assertEquals("pumpkin stew", rs.getString(2));
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getString(2)).isEqualTo("pumpkin stew");
     }
 
     @Test
@@ -58,39 +57,31 @@ public class ExtensionTest {
         ResultSet rs =
                 stat.executeQuery(
                         "select rowid, name, ingredients from recipe where recipe match 'onions'");
-        assertTrue(rs.next());
-        assertEquals("pumpkin stew", rs.getString(2));
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getString(2)).isEqualTo("pumpkin stew");
     }
 
     @Test
     public void extFunctions() throws Exception {
-        {
-            ResultSet rs = stat.executeQuery("pragma compile_options");
-            boolean hasJdbcExtensions = false;
-            while (rs.next()) {
-                String compileOption = rs.getString(1);
-                if (compileOption.equals("JDBC_EXTENSIONS")) {
-                    hasJdbcExtensions = true;
-                    break;
-                }
-            }
-            rs.close();
-            // SQLite has to be compiled with JDBC Extensions for this test to
-            // continue.
-            assumeTrue(hasJdbcExtensions);
-        }
-        {
-            ResultSet rs = stat.executeQuery("select cos(radians(45))");
-            assertTrue(rs.next());
-            assertEquals(0.707106781186548, rs.getDouble(1), 0.000000000000001);
-            rs.close();
-        }
+        Utils.assumeJdbcExtensions(conn);
 
         {
             ResultSet rs = stat.executeQuery("select reverse(\"ACGT\")");
-            assertTrue(rs.next());
-            assertEquals("TGCA", rs.getString(1));
+            assertThat(rs.next()).isTrue();
+            assertThat(rs.getString(1)).isEqualTo("TGCA");
             rs.close();
         }
     }
+
+    @Test
+    public void dbstat() throws Exception {
+        assumeThat(Utils.getCompileOptions(conn))
+                .as("SQLite has to be compiled with ENABLE_DBSTAT_VTAB")
+                .contains("ENABLE_DBSTAT_VTAB");
+
+        {
+            boolean result = stat.execute("SELECT * FROM dbstat");
+            assertThat(result).isTrue();
+        }
+    }
 }
